/*
 *  Copyright 2016 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.forms.tool');

/**
 * Do not call this constructor. Declared to and used by the {@see org.ametys.uitool.ToolsManager}
 * @constructor
 * @class The factory to creates page tools.
 * @param {String} id The unique id of the factory
 * @param {Object} config Options are : 'url' : the url to use to display page, with a 'path' parameter to place the page path; 'default-location' : where to place the tool; 'description' : the tooltip to display with following parameters 'siteUrl', 'siteTitle', 'lang', 'path'.
 * @param {String} pluginName The name of the plugin where the factory was declared
 */
org.ametys.forms.tool.FormsToolFactory = function(id, config, pluginName) 
{
	org.ametys.forms.tool.FormsToolFactory.superclass.constructor.call(this, id, config, pluginName);
};

Ext.extend(org.ametys.forms.tool.FormsToolFactory, org.ametys.uitool.tool.ToolFactory, {});

/**
 * Creates a tool of type {@see org.ametys.cms.tool.content.ContentTool} or activate the existing one.
 * There is one tool per content.
 * @param {Object} params The params used by the factory is 'id' that is the content id. Parameters are transmitted to the content tool.
 * @return {Ext.org.ametys.uitool.tool.Tool} The tool to open.
 */
org.ametys.forms.tool.FormsToolFactory.prototype.openTool = function (params)
{
	var idTool = this._id + params['id'];
	
	if (org.ametys.uitool.ToolsManager.getInstance().getTool(idTool) == null)
	{
		var tool = new org.ametys.forms.tool.FormsTool(idTool, this.getPluginName());
		
		if (params.label)
	    {
		    var defaultTitle = this._config["title"];
		    this._config["title"] = this._config["title"] + ": " + params.label;
		    tool.setConfiguration(this._config);
		    this._config["title"] = defaultTitle;
	    }
		else
	    {
		    tool.setConfiguration(this._config);
	    }
		
		tool.setFactory(this);
		
		org.ametys.uitool.ToolsManager.getInstance().addUITool (tool, this._config['default-location']);
	}
	else
	{
		// Tool does already exists => Tool activation
		tool = org.ametys.uitool.ToolsManager.getInstance().getTool(idTool);
	}

	tool.setParams(params);
	tool.activate();
	
	return tool;
}



/**
 * Destroy the tool.
 * @param {org.ametys.uitool.tool.Tool} tool The tool to close.
 */
org.ametys.forms.tool.FormsToolFactory.prototype.closeTool = function (tool)
{
	org.ametys.uitool.ToolsManager.getInstance().removeUITool (tool);
}
