/*
 *  Copyright 2016 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.plugins.forms.workflow');

org.ametys.plugins.forms.workflow.FormEntriesWorkflowTab = function(id, configuration, pluginName, tabPanel) 
{
	org.ametys.plugins.forms.workflow.FormEntriesWorkflowTab.superclass.constructor.call(this, id, configuration, pluginName, tabPanel);
	
	if (configuration['workflow-name'] != null)
	{
	    this._workflowNameRegexp = new RegExp(configuration['workflow-name']);
	}
}

Ext.extend(org.ametys.plugins.forms.workflow.FormEntriesWorkflowTab, org.ametys.cms.ribbon.tab.SelectionTab, {});

/**
 * @private
 * @property {RegExp} _workflowNameRegexp The workflow name regular expression to match
 */
org.ametys.plugins.forms.workflow.FormEntriesWorkflowTab.prototype._workflowNameRegexp;

/**
 * @private
 * Test a target. Does it match ?
 * @return {org.ametys.messagebus.message.MessageTarget} The target to check
 */
org.ametys.plugins.forms.workflow.FormEntriesWorkflowTab.prototype._testTarget = function(target)
{
	var matchSelection = org.ametys.plugins.forms.workflow.FormEntriesWorkflowTab.superclass._testTarget.call(this, target);
	if (!matchSelection)
	{
		return false;
	}
	
	var contentFormTarget = org.ametys.messagebus.message.MessageTargetHelper.findFirst([target], this._testContentFormTarget.createDelegate(this));
	if (contentFormTarget)
	{
		var workflowName = contentFormTarget.getParameters().workflowName;
		if (this._workflowNameRegexp != null && !this._workflowNameRegexp.test(workflowName))
		{
			// Wrong tab
			return false;
		}
		
		if (this._workflowNameRegexp == null && workflowName)
		{
			// Do not display the tab with no workflow in that case
			return false;
		}
	}
	
	return true;
}

org.ametys.plugins.forms.workflow.FormEntriesWorkflowTab.prototype._testContentFormTarget = function(target)
{
	return target.getType() == 'content-form';
}